import sys

from PyQt4.QtGui import QApplication, QDockWidget, QTextBrowser, QSplitter, QTextDocument, QMainWindow
from PyQt4.QtCore import Qt, SIGNAL, QUrl, QVariant
from PyQt4.QtHelp import QHelpEngine

class Help(QMainWindow):
    def __init__(self, mainWindow):
        QMainWindow.__init__(self)

        # create help window
        helpwindow = QDockWidget(self)
        helpwindow.setFloating(False)
        helpwindow.setFeatures(QDockWidget.NoDockWidgetFeatures)

        # create QSplitter
        self.__mainWidget = QSplitter(Qt.Horizontal)

        # create helper engine and set it up. QHelpEngine inherits QHelpEngineCore
        # and provides several widgets, including the a view displaying the table
        # of content (QHelpEngine.contentWidget()). QHelpEngine is used to "extract"
        # data from compressed help files.
        self.__helper = QHelpEngine("/path/to/help.qhc", self)
        self.__helper.setupData()

        # Get the content widget and instanciate HelpBrowser (defined below).
        # The __helper.contentWidget() returns a widget allowing to display
        # the table of content of the help.
        self.__content = self.__helper.contentWidget()
        self.__helpBrowser = HelpBrowser(self.__mainWidget, self.__helper)

        # build widget
        self.__mainWidget.insertWidget(0, self.__content)
        self.__mainWidget.insertWidget(1, self.__helpBrowser)
        self.__mainWidget.setStretchFactor(1, 1)
        helpwindow.setWidget(self.__mainWidget)
        self.addDockWidget(Qt.TopDockWidgetArea, helpwindow)

        # connect the TOC to the help browser. The signal linkActivated(QUrl) is emitted
        # when the user click on one of the link of the table of content.
        self.__helper.contentWidget().linkActivated.connect(self.__helpBrowser.setSource)

class   HelpBrowser(QTextBrowser):
        def __init__(self, parent, help_engine):
           QTextBrowser.__init__(self)
           self.__helpEngine = help_engine

        def loadResources(self, type, url):
            """
            This method is an overload of the method QTextBrowser.loadResources
            It should be called when the document refered by `url`
            is loaded, and then for each images and style sheet in the document.
            If the url passed in parameter starts with 'qthelp', it means that
            we want to load a file from the compressed documentation, so
            QHelpEngine.fileData(url) is called. For all other urls, the default
            implementation from QTextBrowser is called.

            The parameter `url` is a QUrl and corresponds to the resource we want
            to load (qthelp://url/page.html for example).

            `type` is a flag indicating which type of resource musts be loaded :
            it ca take three values : HtmlResource, ImageResource and 
            StyleSheetResource  (which respectively corresponds to .html pages,
            images and .css files).

            """
            if url.scheme() != "qthelp":   
                return super(HelpBrowser, self).loadResource(type, url)
            return QVariant(self.__helpEngine.fileData(url))
 
if __name__ == '__main__':
    a = QApplication(sys.argv)
    help = Help(QMainWindow)
    help.show()
    sys.exit(a.exec_())
